# Grid ThingZ

Grid ThingZ is a lightweight python library created to manage 2d data structures in a simple and user-friendly way.
* [Wiki](https://github.com/Zachary99/gridThingZ/wiki/Home)

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install Grid Things.

```bash
pip install gridThings-Zephyrrus
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)